#! /usr/bin/env python

##########################################
#
# petitprogrammedenuit.py
#
#  Wrapper to quickly create an AGN list in SIMPUT format and a list of
#  meta-descriptions of the simulated sources.
#
#  Input requires a standard 'AGNlistCfg' file with a list of required keywords.
#
#
#  Created: N.Clerc/MPE -- 2012
#
#  Note: the name of the script is not self-explanatory. Historically linked to
#        the long execution times overnight...
#
#
##########################################

import sys
sys.path.append('scripts') # Optional - only if your scripts are located in some scripts/ directory
import mk_gilli_distribution as gd
import numpy as np
import pyfits
import string
import os
import make_bkgpatch

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Check command lime
check = map(string.lower,sys.argv)
if(len(sys.argv) != 2):
    print "Syntax:"
    print "\t%s config.cfg" % sys.argv[0]
    sys.exit(1)


#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Read configuration file
lines = file(sys.argv[1]).readlines()
intlst=[]
floatlst=['RACEN','DECCEN','SQSIDE','RA1','RA2','DEC1','DEC2','FIXNH']
boollst = ['IMPOSENBR']
pparameters={}
for i in lines:
    if(i[0] == '#'):
        continue
    items = i.split(':')
    items = map(string.strip,items)
    items[1] = items[1].split('#')[0]
    items[1] = string.strip(items[1])
    if(items[0] == 'DIRTEMP'):
        if(not os.path.isdir(items[1])):
            print "ERROR: Directory DIRTEMP not found"
            sys.exit(1)
    if(items[0] in floatlst):
        try:
            items[1] = float(items[1])
        except:
            print "ERROR: the %s must be a float!" % items[0]
            sys.exit(1)
    if(items[0] in boollst):
        try:
            items[1] = items[1] in ['True','true','t','T']
        except:
            print "ERROR: the %s must be a True (true,t,T) anything else is False!" % items[0]
            sys.exit(1)
    pparameters[items[0]] = items[1]

#-----------------------------



cosm = {"omega_M_0":0.3,"omega_lambda_0":0.7,'h':0.72,"omega_k_0":0.}

geomtype = pparameters["GEOMTYPE"]
if(geomtype == 'projcircle'):
    myradius = np.sqrt(2*(pparameters["SQSIDE"]/2.)**2)
    geometry = [pparameters["RACEN"],pparameters["DECCEN"],myradius]
if(geomtype == 'angularbox'):
    geometry = [[pparameters["RA1"],pparameters["RA2"]],[pparameters["DEC1"],pparameters["DEC2"]]]


#print geometry
make_bkgpatch.make_bkgpatch('toto_t1.fits',area_def=geometry,area_type=geomtype,norm052=-1,dir='./BACKSPEC/',specfile='boller_newback_noagn.spec')

sys.exit()

r = gd.gilli_realisation(pparameters["SIMPUTNAME"],cosm,area_def=geometry,area_type=geomtype,
                         dirtemp=pparameters["DIRTEMP"],
                         specBank=['Banks/unabs_bank.fits','Banks/cthin_bank.fits','Banks/cthick_bank.fits'],
                         fullSpec=False,fixGalNH=pparameters["FIXNH"],impose_number=pparameters["IMPOSENBR"])

# Extra-nice: write a summary file containing meta-data for all sources created by
# the script. Useful when looking up for source properties (it does not follow
# the SIMPUT format, it is just another FITS file).
oo=pyfits.Column(name='SimputID',format='64A',array=r["simputid"])
aa=pyfits.Column(name='log10LX',format='E',array=np.log10(r["lum"]))
aa2=pyfits.Column(name='log10LX052',format='E',array=np.log10(r["lum052"]))
bb=pyfits.Column(name='z',format='E',array=r["z"])
cc=pyfits.Column(name='lnh',format='E',array=r["logNh"])
dd=pyfits.Column(name='gamma',format='E',array=r["gamma"])
ee=pyfits.Column(name='f_052',format='E',array=r["f052"])
ff=pyfits.Column(name='f_210',format='E',array=r["f210"])
gg=pyfits.Column(name='f_510',format='E',array=r["f510"])
hh=pyfits.Column(name='f_052_abs',format='E',array=r["f052_abs"])
cols=pyfits.ColDefs([oo,aa,aa2,bb,cc,dd,ee,ff,gg,hh])
tbhdu=pyfits.BinTableHDU.from_columns(cols)
tbhdu.writeto(pparameters["LISTNAME"])

